@@ -10,5 +10,7 @@ from ._errors import (
     TranslationLanguageNotAvailable,
     NoTranscriptAvailable,
     CookiePathInvalid,
-    CookiesInvalid
+    CookiesInvalid,
+    FailedToCreateConsentCookie,
+    YouTubeRequestFailed,
 )
